@@ -5,6 +5,7 @@ import (
 	"github.com/spf13/cobra"
 
 	"github.com/omegion/ssh-manager/internal/controller"
+	"github.com/omegion/ssh-manager/internal/provider"
 )
 
 // setupListCommand sets default flags.
@@ -14,6 +15,8 @@ func setupListCommand(cmd *cobra.Command) {
 	if err := cmd.MarkFlagRequired("provider"); err != nil {
 		log.Fatalf("Lethal damage: %s\n\n", err)
 	}
+
+	cmd.Flags().String("bucket", "", "S3 Bucket Name")
 }
 
 // List acquires Manager keys from given provider.
@@ -23,8 +26,15 @@ func List() *cobra.Command {
 		Short: "List Manager keys from given provider.",
 		RunE: func(cmd *cobra.Command, args []string) error {
 			providerName, _ := cmd.Flags().GetString("provider")
+			bucket, _ := cmd.Flags().GetString("bucket")
 
-			items, err := controller.NewManager(&providerName).List()
+			options := provider.ListOptions{}
+
+			if bucket != "" {
+				options.Bucket = &bucket
+			}
+
+			items, err := controller.NewManager(&providerName).List(options)
 			if err != nil {
 				return err
 			}
