@@ -11,9 +11,9 @@ import (
 
 func main() {
 	root := &cobra.Command{
-		Use:          "vault-unseal",
-		Short:        "Vault Auto Unseal",
-		Long:         "CLI command to automatically unseal Vault",
+		Use:          "ssh-manager",
+		Short:        "SSH Key Manager.",
+		Long:         "SSH Key Manager for 1Password, Bitwarden and AWS S3.",
 		SilenceUsage: true,
 	}
 
